<h1 align="center"> Siam_Phisher </h1>

<h3 align="center"> { Made By Siam Rahman }</h3>
<h2 align="center"></h2>
<h4 align="center"> USE THIS TOOL IN 2 METHODS </h4>
<h2 align="center">  METHORD 1 </h2>

### [>] METHOD :
# STEP 1
```
pip uninstall siamphisher
```
# STEP 2

```
pip install siamphisher
```
# STEP 3
### TYPE :
```
siamphisher
```
<h4 align="center">  METHORD 1 RUN SUCCESSFULL </h4>

<h2 align="center">  METHORD 2 </h2>

### [>] METHOD :
# STEP 1
```
rm -rf Siam_Phisher
```
# STEP 2
```
git clone https://github.com/SIAMRAHMAN000/Siam_Phisher
```
# STEP 3
```
cd Siam_Phisher
```
# STEP 4
```
python3 siamphisher.py
```

<h4 align="center">  METHORD 2 RUN SUCCESSFULL </h4>


### [√] Description :

***A python phishing script for login phishing, image phishing, video phishing and many more***

### [+] Installation

##### Install primary dependencies (git, python)

 - For Debian (Ubuntu, Kali-Linux, Parrot)
    - ```sudo apt install git python3 php openssh-client -y```
 - For Arch (Manjaro)
    - ```sudo pacman -S git python3 php openssh --noconfirm```
 - For Redhat(Fedora)
    - ```sudo dnf install git python3 php openssh -y```
 - For Termux
    - ```pkg install git python3 php openssh -y```

##### Clone this repository

 - ```git clone https://github.com/SIAMRAHMAN000/Siam_Phisher```

##### Enter the directory
 - ```cd Siam_Phisher```

##### Install all modules
 - ```pip3 install -r files/requirements.txt```

##### Run the tool
 - ```python3 siamphisher.py```

#### Or, directly run
```
wget https://raw.githubusercontent.com/SIAMRAHMAN000/Siam_Phisher/main/siamphisher.py && python3 siamphisher.py

```
### Docker

 - `sudo docker pull SIAMRAHMAN000/siamphisher`
 - `sudo docker run --rm -it SIAMRAHMAN000/siamphisher`


### Support

OS         | Support Level
-----------|--------------
Linux      | Excellent
Android    | Excellent
iPhone     | Alpha (Recommended docker)
MacOS      | Alpha (Recommended docker)
Windows    | Unsupported (Use docker/virtual-box/vmware)
BSD        | Never tested

#### Options

```
usage: siamphisher.py [-h] [-p PORT] [-t TYPE] [-o OPTION]
                     [-T TUNNELER] [-r REGION] [-S SUBDOMAIN]
                     [-d DIRECTORY] [-f FEST] [-i YTID] [-u URL]
                     [-s DURATION] [-m MODE] [-e TROUBLESHOOT]
                     [--nokey] [--noupdate]

options:
  -h, --help            show this help message and exit
  -p PORT, --port PORT  Siamphisher's server port [Default : 8080]
  -t TYPE, --type TYPE  Siamphisher's phishing type index [Default :
                        null]
  -o OPTION, --option OPTION
                        Siamphisher's template index [ Default : null ]
  -T TUNNELER, --tunneler TUNNELER
                        Tunneler to be chosen while url shortening
                        [Default : Cloudflared]
  -r REGION, --region REGION
                        Region for ngrok and loclx [Default: auto]
  -S SUBDOMAIN, --subdomain SUBDOMAIN
                        Subdomain for ngrok and loclx [Pro Account]
                        (Default: null)
  -d DIRECTORY, --directory DIRECTORY
                        Directory where media files will be saved
                        [Default : /sdcard/Media]
  -f FEST, --fest FEST  Festival name for fest template [Default:
                        Birthday]
  -i YTID, --ytid YTID  Youtube video ID for yttv template [Default :
                        6hHmkInZkMQ (NASA Video)]
  -u URL, --url URL     Redirection url for ip-tracking or login
                        phishing [Default : null]
  -s DURATION, --duration DURATION
                        Media duration while capturing [Default :
                        5000(ms)]
  -m MODE, --mode MODE  Mode of Siamphisher [Default: normal]
  -e TROUBLESHOOT, --troubleshoot TROUBLESHOOT
                        Troubleshoot a tunneler [Default: null]
  --nokey               Use localtunnel without ssh key [Default:
                        False]
  --noupdate            Skip update checking [Default : False]
```

### Features:

 - Multi platform (Supports most linux)
 - 100+ templates
 - Concurrent 4 tunneling (Ngrok, Cloudflared and LocalXpose, LocalHostRun)
 - OTP Support
 - Credentials mailing
 - Easy to use
 - Possible error diagnoser
 - Built-in masking of URL
 - Custom masking of URL
 - URL Shadowing
 - Portable file (Can be run from any directory)
 - Get IP Address and many other details along with login credentials


### Requirements

 - `Python(3)`
   - `requests`
   - `bs4`
   - `rich`
 - `PHP`
 - `SSH`
 - 900MB storage
 
If not found, php, ssh and python modoules will be installed on first run

#### Tested on

 - `Termux`
 - `Ubuntu`
 - `Kali-Linux`
 - `Arch`
 - `Fedora`
 - `Manjaro`

## Usage

1. Run the script
2. Choose a Website
3. Wait sometimes for setting up all
4. Send the generated link to victim
5. Wait for victim login. As soon as he/she logs in, credentials will be captured

## [!] Disclaimer
***This tool is developed for educational purposes. Here it demonstrates how phishing works. If anybody wants to gain unauthorized access to someones social media, he/she may try out this at his/her own risk. You have your own responsibilities and you are liable to any damage or violation of laws by this tool. The author is not responsible for any misuse of Siam Phisher!***

#### Want to show support? Just spread the word and smash the star button

## Code By:

[SIAM RAHMAN](https://github.com/SIAMRAHMAN000/)

## [~] Find Me on :

- [![Github](https://img.shields.io/badge/Github-SIAMRAHMAN000-green?style=for-the-badge&logo=github)](https://github.com/KasRoudra)

- [![Gmail](https://img.shields.io/badge/Gmail-SIAMRAHMAN000-green?style=for-the-badge&logo=gmail)](mailto:kasroudrakrd@gmail.com)

- [![Facebook](https://img.shields.io/badge/Facebook-SIAMRAHMAN000-green?style=for-the-badge&logo=facebook)](https://facebook.com/KasRoudra)

- [![Messenger](https://img.shields.io/badge/Messenger-SIAMRAHMAN000-green?style=for-the-badge&logo=messenger)](https://m.me/skillsiam1245)


